==> texinfo-6.8.90.tar.xz: texinfo-6.8.90/tp/t/results/latex_tests/settitle_and_headings.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'settitle_and_headings'} = {
  'contents' => [
    {
      'contents' => [
        {
          'contents' => [
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'Title '
                    },
                    {
                      'cmdname' => '*',
                      'parent' => {}
                    },
                    {
                      'parent' => {},
                      'text' => ' for a manual'
                    }
                  ],
                  'extra' => {
                    'spaces_after_argument' => '
'
                  },
                  'parent' => {},
                  'type' => 'line_arg'
                }
              ],
              'cmdname' => 'settitle',
              'extra' => {
                'spaces_before_argument' => ' '
              },
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 1,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => '
',
              'type' => 'empty_line'
            },
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'parent' => {},
                      'text' => 'double'
                    }
                  ],
                  'extra' => {
                    'spaces_after_argument' => '
'
                  },
                  'parent' => {},
                  'type' => 'line_arg'
                }
              ],
              'cmdname' => 'headings',
              'extra' => {
                'misc_args' => [
                  'double'
                ],
                'spaces_before_argument' => ' '
              },
              'parent' => {},
              'source_info' => {
                'file_name' => '',
                'line_nr' => 3,
                'macro' => ''
              }
            },
            {
              'parent' => {},
              'text' => '
',
              'type' => 'empty_line'
            }
          ],
          'parent' => {},
          'type' => 'preamble_before_content'
        }
      ],
      'parent' => {},
      'type' => 'before_node_section'
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'chap'
            }
          ],
          'extra' => {
            'spaces_after_argument' => '
'
          },
          'parent' => {},
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'chapter',
      'contents' => [
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => '
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'page',
          'parent' => {}
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'More text
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'parent' => {},
              'text' => '
',
              'type' => 'misc_arg'
            }
          ],
          'cmdname' => 'page',
          'parent' => {}
        },
        {
          'parent' => {},
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'parent' => {},
              'text' => 'Another page
'
            }
          ],
          'parent' => {},
          'type' => 'paragraph'
        }
      ],
      'extra' => {
        'spaces_before_argument' => ' '
      },
      'parent' => {},
      'source_info' => {
        'file_name' => '',
        'line_nr' => 5,
        'macro' => ''
      }
    }
  ],
  'type' => 'document_root'
};
$result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0];
$result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[1]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0];
$result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'contents'}[2]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0];
$result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'args'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[0];
$result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0];
$result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[1]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0];
$result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'args'}[0];
$result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'args'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[2];
$result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[2]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0];
$result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'contents'}[3]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0];
$result_trees{'settitle_and_headings'}{'contents'}[0]{'contents'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[0];
$result_trees{'settitle_and_headings'}{'contents'}[0]{'parent'} = $result_trees{'settitle_and_headings'};
$result_trees{'settitle_and_headings'}{'contents'}[1]{'args'}[0]{'contents'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1]{'args'}[0];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[1]{'args'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[1];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[1]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[2]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[3]{'contents'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[3];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[3]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[4]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[5]{'args'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[5];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[5]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[6]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[7]{'contents'}[0]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[7];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'contents'}[7]{'parent'} = $result_trees{'settitle_and_headings'}{'contents'}[1];
$result_trees{'settitle_and_headings'}{'contents'}[1]{'parent'} = $result_trees{'settitle_and_headings'};

$result_texis{'settitle_and_headings'} = '@settitle Title @* for a manual

@headings double

@chapter chap

@page

More text

@page

Another page
';


$result_texts{'settitle_and_headings'} = '

1 chap
******



More text



Another page
';

$result_sectioning{'settitle_and_headings'} = {
  'structure' => {
    'section_childs' => [
      {
        'cmdname' => 'chapter',
        'extra' => {},
        'structure' => {
          'section_level' => 1,
          'section_number' => 1,
          'section_up' => {}
        }
      }
    ],
    'section_level' => 0
  }
};
$result_sectioning{'settitle_and_headings'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'settitle_and_headings'};

$result_errors{'settitle_and_headings'} = [];


$result_floats{'settitle_and_headings'} = {};



$result_converted{'latex_text'}->{'settitle_and_headings'} = '
\\pagestyle{double}%

\\begin{document}
\\chapter{{chap}}

\\newpage{}%
\\phantom{blabla}%

More text

\\newpage{}%
\\phantom{blabla}%

Another page
';

1;

==> texinfo-7.1.1.tar.xz: texinfo-7.1.1/tp/t/results/latex_tests/settitle_and_headings.pl <==
use vars qw(%result_texis %result_texts %result_trees %result_errors 
   %result_indices %result_sectioning %result_nodes %result_menus
   %result_floats %result_converted %result_converted_errors 
   %result_elements %result_directions_text %result_indices_sort_strings);

use utf8;

$result_trees{'settitle_and_headings'} = {
  'contents' => [
    {
      'contents' => [
        {
          'contents' => [
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'text' => 'Title '
                    },
                    {
                      'cmdname' => '*'
                    },
                    {
                      'text' => ' for a manual'
                    }
                  ],
                  'info' => {
                    'spaces_after_argument' => {
                      'text' => '
'
                    }
                  },
                  'type' => 'line_arg'
                }
              ],
              'cmdname' => 'settitle',
              'info' => {
                'spaces_before_argument' => {
                  'text' => ' '
                }
              },
              'source_info' => {
                'file_name' => '',
                'line_nr' => 1,
                'macro' => ''
              }
            },
            {
              'text' => '
',
              'type' => 'empty_line'
            },
            {
              'args' => [
                {
                  'contents' => [
                    {
                      'text' => 'double'
                    }
                  ],
                  'info' => {
                    'spaces_after_argument' => {
                      'text' => '
'
                    }
                  },
                  'type' => 'line_arg'
                }
              ],
              'cmdname' => 'headings',
              'extra' => {
                'misc_args' => [
                  'double'
                ]
              },
              'info' => {
                'spaces_before_argument' => {
                  'text' => ' '
                }
              },
              'source_info' => {
                'file_name' => '',
                'line_nr' => 3,
                'macro' => ''
              }
            },
            {
              'text' => '
',
              'type' => 'empty_line'
            }
          ],
          'type' => 'preamble_before_content'
        }
      ],
      'type' => 'before_node_section'
    },
    {
      'args' => [
        {
          'contents' => [
            {
              'text' => 'chap'
            }
          ],
          'info' => {
            'spaces_after_argument' => {
              'text' => '
'
            }
          },
          'type' => 'line_arg'
        }
      ],
      'cmdname' => 'chapter',
      'contents' => [
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'text' => '
',
              'type' => 'rawline_arg'
            }
          ],
          'cmdname' => 'page'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'text' => 'More text
'
            }
          ],
          'type' => 'paragraph'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'args' => [
            {
              'text' => '
',
              'type' => 'rawline_arg'
            }
          ],
          'cmdname' => 'page'
        },
        {
          'text' => '
',
          'type' => 'empty_line'
        },
        {
          'contents' => [
            {
              'text' => 'Another page
'
            }
          ],
          'type' => 'paragraph'
        }
      ],
      'info' => {
        'spaces_before_argument' => {
          'text' => ' '
        }
      },
      'source_info' => {
        'file_name' => '',
        'line_nr' => 5,
        'macro' => ''
      }
    }
  ],
  'type' => 'document_root'
};

$result_texis{'settitle_and_headings'} = '@settitle Title @* for a manual

@headings double

@chapter chap

@page

More text

@page

Another page
';


$result_texts{'settitle_and_headings'} = '

1 chap
******



More text



Another page
';

$result_sectioning{'settitle_and_headings'} = {
  'structure' => {
    'section_childs' => [
      {
        'cmdname' => 'chapter',
        'structure' => {
          'section_level' => 1,
          'section_number' => 1,
          'section_up' => {}
        }
      }
    ],
    'section_level' => 0
  }
};
$result_sectioning{'settitle_and_headings'}{'structure'}{'section_childs'}[0]{'structure'}{'section_up'} = $result_sectioning{'settitle_and_headings'};

$result_errors{'settitle_and_headings'} = [];


$result_floats{'settitle_and_headings'} = {};



$result_converted{'latex_text'}->{'settitle_and_headings'} = '
\\pagestyle{double}%

\\begin{document}
\\chapter{{chap}}

\\newpage{}%
\\phantom{blabla}%

More text

\\newpage{}%
\\phantom{blabla}%

Another page
';

1;
